// Note: Current version of DLL is using _outp() and _inp() calls which are not allowed under WinXP and later.
// Therefore appications which are using this .dll must run in Windows98 compatible mode. Do not forget to setup by right click.
// However you are free to rewrite it....


#include "stdafx.h"
#include "WDT.h"
#include <windows.h>
#include <commctrl.h>

extern "C" 
	{		
		int _cdecl _inp(unsigned short);
        int _cdecl _outp(unsigned short, int);
	}



#ifdef _MANAGED
#pragma managed(push, off)
#endif

BOOL APIENTRY DllMain( HMODULE hModule,
                       DWORD  ul_reason_for_call,
                       LPVOID lpReserved
					 )
{
	switch (ul_reason_for_call)
	{
	case DLL_PROCESS_ATTACH:
	case DLL_THREAD_ATTACH:
	case DLL_THREAD_DETACH:
	case DLL_PROCESS_DETACH:
		break;
	}
    return TRUE;
}

#ifdef _MANAGED
#pragma managed(pop)
#endif

/*

Description:
This function set WDT0 include write the desired counter value 
	  and the time out will generate signal setting.

Note:
  Input parameter: 
	1)unsigned int nTime means write the desired counter value to WDT0.
		unit is millisecond. range: > 0 and < 512 * 1000.
	2)unsigned char nEvent means the time out will generate signal setting.
  Return value: 0,1,2
	0 means set WDT0 succeed
	1 means input parameter nTime inefficacy
	2 means input parameter nEvent inefficacy
*/

//Set WDT0 desired counter value and the time out will generate event
extern "C" WDT_API int SetWDT0(unsigned int nTime, unsigned char nEvent)
{
	unsigned long lTime;
	char c;
	
	if (nTime >= 512 * 1000)
		return 1;
	if (nEvent > 0xd0 || nEvent < 0x10)
		return 2;

	lTime = 0x20L * nTime;  
	
	_outp(0x22,0x13);		// Lock register
	_outp(0x23,0xc5);		// Unlock config. register
	
	_outp(0x22,0x3b);       //set time
	_outp(0x23,(lTime>>16)&0xff);
	_outp(0x22,0x3a);
	_outp(0x23,(lTime>> 8)&0xff);
	_outp(0x22,0x39);
	_outp(0x23,(lTime>> 0)&0xff);
	
	_outp(0x22,0x38);       //set event
	c = _inp(0x23);
	c &= 0x0f;
	c |= nEvent;			// Reset system. For example, 0x50 to trigger IRQ7
	_outp(0x22,0x38);
	_outp(0x23,c);
							// Enable watchdog timer
	_outp(0x22,0x37);
	c = _inp(0x23);
	c |= 0x40;
	_outp(0x22,0x37);
	_outp(0x23,c);
	_outp(0x22,0x13);		// Lock register
	_outp(0x23,0x00);		// Lock config. register
	
	return 0;
}
/*

Description:
This function set WDT1 include write the desired counter value 
	  and the time out will generate signal setting.

Note:
  Input parameter: 
	1)unsigned int nTime means write the desired counter value to WDT1.
		unit is millisecond. range: > 0 and < 512 * 1000.
	2)unsigned char nEvent means the time out will generate signal setting.
  Return value: 0,1,2
	0 means set WDT1 succeed
	1 means input parameter nTime inefficacy
	2 means input parameter nEvent inefficacy
*/

//Set WDT1 desired counter value and the time out will generate event
extern "C" WDT_API int SetWDT1(unsigned int nTime, unsigned char nEvent)
{
	unsigned long lTime;
	unsigned char c;

	if (nEvent > 0xd0 || nEvent < 0x10)
		return 1;

	lTime = 0x20L * nTime;

	_outp(0x6c, (lTime >> 16) & 0xff);
	_outp(0x6b, (lTime >> 8) & 0xff);
	_outp(0x6a, (lTime >> 0) & 0xff);
							// Reset system. For example, 0x50 to trigger IRQ7
	_outp(0x69, nEvent);
							// Enable watchdog timer
	c = _inp(0x68);
	c |= 0x40;
	_outp(0x68, c);

	return 0;
}
/*

Description:
This function will reset WDT0.

*/

//This function will reset WDT0
extern "C" WDT_API void ResetWDT0(void)
{
	_outp(0x22,0x13);	// Unlock register
	_outp(0x23,0xc5);
	unsigned char c = _inp(0x23);
	_outp(0x22,0x3c);
	_outp(0x22,0x3c);
	_outp(0x23,c|0x40);
	_outp(0x22,0x13);	// Lock register
	_outp(0x23,0x00);
}

/*

Description:
This function will reset WDT1

*/

//This function will reset WDT1
extern "C" WDT_API void ResetWDT1(void)
{
	_outp(0x67, 0x00);
}

/*
Description:
This function will disable WDT0

*/

//This function will disable WDT0
extern "C" WDT_API void DisableWDT0(void)
{
	unsigned char c;
	_outp(0x22,0x13); // Lock register
	_outp(0x23,0xc5); // Unlock config. register
	
	_outp(0x22,0x37); // Disable watchdog timer
	c = _inp(0x23);
	c &= 0xBF;
	_outp(0x22,0x37);
	_outp(0x23,c);
	_outp(0x22,0x13); // Lock register
	_outp(0x23,0x00); // Lock config. register
}

/*
Description:
This function will disable WDT1

*/

//This function will disable WDT1
extern "C" WDT_API void DisableWDT1(void)
{
	unsigned char c;
	c = _inp(0x68);
	c &= 0xBF;        // Disable watchdog timer
	_outp(0x68, c);
}
//--end-------------------------------------------------

